<?php
/**
 * Automation action class for MRM Autoamtion
 *
 * Class AddContactNote
 *
 * @package MintMail\App\Internal\Automation\Action
 */

namespace MintMail\App\Internal\Automation\Action;

use Mint\Mrm\Internal\Traits\Singleton;
use MintMail\App\Internal\Automation\Action\AbstractAutomationAction;
use MintMail\App\Internal\Automation\HelperFunctions;
use MintMail\App\Internal\Automation\ActionScheduler;
use Mint\MRM\DataStores\ContactData;
use Mint\MRM\DataBase\Models\ContactModel;
use Mint\MRM\Admin\API\Controllers\ListController;
use Mint\MRM\DataBase\Models\NoteModel;
use Mint\MRM\DataStores\NoteData;

/**
 * AddContactNote action
 *
 * Class AddContactNote
 *
 * @package MintMail\App\Internal\Automation\Action
 */
class AddContactNote extends AbstractAutomationAction {

	use Singleton;
	/**
	 * Action scheduler.
	 *
	 * @var $action_scheduler
	 */
	private $action_scheduler;
	/**
	 * Initialization
	 */
	public function __construct() {
		$this->action_scheduler = new ActionScheduler();
	}


	/**
	 * Get action name
	 *
	 * @return String
	 * @since  1.0.0
	 */
	public function get_name() {
		return __( 'Add contact note', 'mailmint-pro' );
	}

	/**
	 * Process Contact note data.
	 *
	 * @param array $data Get All data.
	 */
	public function process( $data ) {
		if ( $data ) {
			$email = isset( $data['data']['user_email'] ) ? $data['data']['user_email'] : '';
			if ( $email ) {
				$contact_id = ContactModel::get_id_by_email( $email );
				if ( $contact_id ) {
					$step_data     = HelperFunctions::get_step_data( $data['automation_id'], $data['step_id'] );
					$notes         = array(
						'title'       => __( 'Subscriber double opt-in confirmed', 'mailmint-pro' ),
						'description' => __( 'Subscriber confirmed double opt-in', 'mailmint-pro' ),
						'type'        => 'MRM Note',
						'is_public'   => 1,
						'status'      => 1,
						'created_by'  => 1,
					);
					$note_settings = isset( $step_data['settings']['note_settings'] ) ? $step_data['settings']['note_settings'] : $notes;
					$note          = new NoteData( $note_settings );
					NoteModel::insert( $note, $contact_id );
				}
			}

			$next_step = HelperFunctions::get_next_step( $data['automation_id'], $data['step_id'] );
			HelperFunctions::update_job( $data['automation_id'], isset( $next_step['step_id'] ) ? $next_step['step_id'] : null, isset( $next_step['step_id'] ) ? 'processing' : 'completed' );
			if ( $next_step ) {
				$next_step['data'] = $data['data'];
				$scheduler_data    = array( $next_step );
				if ( $this->action_scheduler->hasScheduledAction( MINT_PROCESS_AUTOMATION ) ) {
					return;
				}
				$this->action_scheduler->enqueue( MINT_PROCESS_AUTOMATION, $scheduler_data );
			}
		}
	}


}
