<?php
/**
 * Automation action class for MRM Autoamtion
 *
 * Class CreateCoupon
 *
 * @package MintMail\App\Internal\Automation\Action
 */

namespace MintMail\App\Internal\Automation\Action;

use Mint\Mrm\Internal\Traits\Singleton;
use MintMail\App\Internal\Automation\Action\AbstractAutomationAction;
use MintMail\App\Internal\Automation\HelperFunctions;
use MintMail\App\Internal\Automation\ActionScheduler;
use Mint\MRM\DataStores\ContactData;
use Mint\MRM\DataBase\Models\ContactModel;

/**
 * CreateCoupon action
 *
 * Class CreateCoupon
 *
 * @package MintMail\App\Internal\Automation\Action
 */
class CreateCoupon extends AbstractAutomationAction {

	use Singleton;
	/**
	 * Action scheduler.
	 *
	 * @var $action_scheduler
	 */
	private $action_scheduler;
	/**
	 * Initialization
	 */
	public function __construct() {
		$this->action_scheduler = new ActionScheduler();
	}


	/**
	 * Get action name
	 *
	 * @return String
	 * @since  1.0.0
	 */
	public function get_name() {
		return __( 'Create Coupon', 'mailmint-pro' );
	}


	/**
	 * Process.
	 *
	 * @param array $data Get All data.
	 */
	public function process( $data ) {
		if ( $data ) {
			if ( isset( $data['automation_id'], $data['step_id'] ) ) {
				$step_data       = HelperFunctions::get_step_data( $data['automation_id'], $data['step_id'] );
				$default_coupon  = array(
					'code'             => 'mint_2023',
					'description'      => 'Mint welcome coupon',
					'type'             => 'percent', // discount type can be 'fixed_cart', 'percent' or 'fixed_product', defaults to 'fixed_cart'.
					'amount'           => 20,
					'is_free_shipping' => true,
					'expire_date'      => '31-12-2022',
				);
				$coupon_settings = isset( $step_data['settings']['coupon_settings'] ) ? $step_data['settings']['coupon_settings'] : $default_coupon;
				if ( $coupon_settings ) {
					$this->create_coupon( $coupon_settings );
				}
			}

			$next_step = HelperFunctions::get_next_step( $data['automation_id'], $data['step_id'] );
			HelperFunctions::update_job( $data['automation_id'], isset( $next_step['step_id'] ) ? $next_step['step_id'] : null, isset( $next_step['step_id'] ) ? 'processing' : 'completed' );
			if ( $next_step ) {
				$next_step['data'] = $data['data'];
				$scheduler_data    = array( $next_step );
				if ( $this->action_scheduler->hasScheduledAction( MINT_PROCESS_AUTOMATION ) ) {
					return;
				}
				$this->action_scheduler->enqueue( MINT_PROCESS_AUTOMATION, $scheduler_data );
			}
		}
	}


	/**
	 * Create coupon.
	 *
	 * @param array $args Get All data.
	 */
	private function create_coupon( $args = array() ) {
		if ( isset( $args['code'], $args['type'], $args['amount'] ) && !empty( $args['code'] ) ) {
			$coupon = new \WC_Coupon();

			$coupon->set_code( $args['code'] );
			if ( !empty( $args['description'] ) ) {
				$coupon->set_description( $args['description'] );
			}

			if ( !empty( $args['type'] ) ) {
				$coupon->set_discount_type( $args['type'] );
			}

			if ( !empty( $args['amount'] ) ) {
				$coupon->set_amount( $args['amount'] );
			}

			$coupon->set_free_shipping( isset( $args['set_free_shipping'] ) ? $args['set_free_shipping'] : true );

			if ( !empty( $args['expire_date'] ) ) {
				$coupon->set_date_expires( $args['expire_date'] );
			}
			$coupon->save();
		}
	}

}
