<?php
/**
 * Automation action class for MRM Autoamtion
 *
 * Class Webhook
 *
 * @package MintMail\App\Internal\Automation\Action
 */

namespace MintMail\App\Internal\Automation\Action;

use Mint\Mrm\Internal\Traits\Singleton;
use MintMail\App\Internal\Automation\HelperFunctions;
use MintMail\App\Internal\Automation\ActionScheduler;
use Mint\MRM\DataBase\Models\ContactModel;
use function Groundhogg\set_request_var;

/**
 * Webhook action
 *
 * Class Webhook
 *
 * @package MintMail\App\Internal\Automation\Action
 */
class WebHookOutgoing extends AbstractAutomationAction {

	use Singleton;
	/**
	 * Action scheduler.
	 *
	 * @var $action_scheduler
	 */
	private $action_scheduler;
	/**
	 * Initialization
	 */
	public function __construct() {
		$this->action_scheduler = new ActionScheduler();
	}


	/**
	 * Get action name
	 *
	 * @return String
	 * @since  1.0.0
	 */
	public function get_name() {
		return __( 'Webook', 'mailmint-pro' );
	}


	/**
	 * Process.
	 *
	 * @param array $data Get All data.
	 */
	public function process( $data ) {
		if ( $data ) {
			$email         = isset( $data['data']['user_email'] ) ? $data['data']['user_email'] : '';
			$automation_id = isset( $data['automation_id'] ) ? $data['automation_id'] : '';
			$step_id       = isset( $data['step_id'] ) ? $data['step_id'] : '';
			$log_payload   = array(
				'automation_id' => $data['automation_id'],
				'step_id'       => $data['step_id'],
				'status'        => 'hold',
				'identifier'    => $data['identifier'],
				'email'         => !empty( $data['data']['user_email'] ) ? $data['data']['user_email'] : '',
			);
			HelperFunctions::update_log( $log_payload );
			if ( $email && $automation_id && $step_id && HelperFunctions::maybe_user( $data['data']['user_email'] ) ) {
				$step_data = HelperFunctions::get_step_data( $automation_id, $step_id );
				if ( isset( $step_data['settings']['message_data'] ) ) {
					$settings  = $step_data['settings']['message_data'];
					$body_data = array(
						'body_request' => isset( $settings['body_request'] ) ? $settings['body_request'] : '',
						'body_data'    => isset( $settings['body_request_data'] ) ? $settings['body_request_data'] : array(),
					);

					$header_data  = array(
						'header_request' => isset( $settings['header_request'] ) ? $settings['header_request'] : '',
						'header_data'    => isset( $settings['header_request_data'] ) ? $settings['header_request_data'] : array(),
					);
					$data_format  = isset( $settings['data_format'] ) ? $settings['data_format'] : 'form';
					$method       = isset( $settings['method'] ) ? $settings['method'] : 'GET';
					$method       = strtoupper( $method );
					$url          = $this->get_url( $settings );
					$content_type = $this->get_content_type( $method, $data_format );
					$header       = $this->prepare_header( $header_data, $data_format, $method, $url );
					$body         = $this->prepare_body( $body_data, $email );
					if ( 'GET' === $method ) {
						$url = add_query_arg( $body, $url );
					}
					$payload      = array(
						'url'          => $url,
						'method'       => $method,
						'data_format'  => $data_format,
						'content_type' => $content_type,
						'request_body' => ( 'POST' === $method ) ? $body : null,
						'header'       => $header,
					);
					$request_args = $this->prepare_request_args( $payload );
					$this->send_webhook_data( $url, $request_args );
				}
			}
			if ( !isset( $data['double_optin'] ) ) {
				$next_step = HelperFunctions::get_next_step( $data['automation_id'], $data['step_id'] );
				HelperFunctions::update_job( $data['automation_id'], isset( $next_step['step_id'] ) ? $next_step['step_id'] : null, isset( $next_step['step_id'] ) ? 'processing' : 'completed' );
				if ( $next_step ) {
					$next_step['data']       = $data['data'];
					$next_step['identifier'] = $data['identifier'];
					$scheduler_data          = array( $next_step );
					if ( $this->action_scheduler->hasScheduledAction( MINT_PROCESS_AUTOMATION ) ) {
						return;
					}
					$this->action_scheduler->enqueue( MINT_PROCESS_AUTOMATION, $scheduler_data );
				}
			}
		}
	}


	/**
	 * Prepare herder data.
	 *
	 * @param array  $header_data Data.
	 * @param string $data_format Get Date Formate.
	 * @param string $method Get received method.
	 * @param string $url Get URL.
	 * @return array
	 * @since 1.0.0
	 */
	private function prepare_header( $header_data, $data_format, $method, $url ) {
		$content_type        = $this->get_content_type( $method, $data_format );
		$data                = array(
			'Content-Type'        => $content_type,
			'X-WC-Webhook-Source' => $url,
		);
		$maybe_custom_header = !empty( $header_data['header_request'] ) && 'no_hearder' === $header_data['header_request'] ? false : true;
		if ( $maybe_custom_header && is_array( $header_data['header_data'] ) ) {
			foreach ( $header_data['header_data'] as $herder ) {
				if ( isset( $herder['header_key'], $herder['header_value'] ) ) {
					$key                    = str_replace( ' ', '-', $herder['header_key'] );
					$data[ 'X-WC-' . $key ] = $herder['header_value'];
				}
			}
		}
		return $data;
	}


	/**
	 * Prepare herder data
	 *
	 * @param array  $body_data Data.
	 * @param string $email Get email address.
	 * @return array
	 * @since 1.0.0
	 */
	private function prepare_body( $body_data, $email ) {
		$data = array();
		if ( isset( $body_data['body_request'], $body_data['body_data'] ) ) {
			$contact_id = ContactModel::get_id_by_email( $email );
			$contact    = ContactModel::get( $contact_id );
			if ( 'raw' === $body_data['body_request'] ) {
				$data = $contact;
			} else {
				foreach ( $body_data['body_data'] as $item ) {
					if ( empty( $item['body_key'] ) || empty( $item['body_value'] ) ) {
						continue;
					}
					$item['body_key']          = str_replace( ' ', '_', $item['body_key'] );
					$data[ $item['body_key'] ] = $this->replace_form_value( $contact, $item['body_value'] );
				}
			}
		}
		return $data;
	}


	/**
	 * Get request url
	 *
	 * @param array $settings Settings.
	 * @return string
	 * @since 1.0.0
	 */
	private function get_url( $settings ) {
		$url = '';
		if ( isset( $settings['remote_url'] ) ) {
			$url = $settings['remote_url'];
		}
		return $url;
	}


	/**
	 * Send webhook data.
	 *
	 * @param string $request_url Webhook url.
	 * @param array  $request_args Request data.
	 *
	 * @return void
	 * @since 1.0.0
	 */
	private function send_webhook_data( $request_url, $request_args ) {
		wp_remote_request( $request_url, $request_args );
	}


	/**
	 * Prepare common request body for webhook
	 *
	 * @param array $payload Payload data.
	 * @return array
	 */
	private function prepare_request_args( $payload ) {
		if ( isset( $payload['method'], $payload['data_format'] ) ) {
			if ( 'GET' !== $payload['method'] ) {
				if ( isset( $payload['data_format'] ) ) {
					if ( 'form' === $payload['data_format'] ) {
						$request_body = $payload['request_body'];
						$request_body = http_build_query( $request_body );
					} elseif ( 'json' === $payload['data_format'] ) {
						$request_body = wp_json_encode( $payload['request_body'] );
					}
				}
			}

			$request_args = array(
				'body'      => $request_body,
				'method'    => $payload['method'],
				'headers'   => $payload['header'],
				'sslverify' => 1,
			);
			return $request_args;
		}
		return array();
	}

	/**
	 * Get Content Type
	 *
	 * @param string $method Submit method.
	 * @param string $data_format Data format.
	 * @return string
	 */
	private function get_content_type( $method, $data_format ) {
		$content_type = 'application/json';
		if ( 'GET' !== $method ) {
			if ( 'form' === $data_format ) {
				$content_type = 'application/x-www-form-urlencoded';
			} elseif ( 'json' === $data_format ) {
				$content_type = 'application/json; charset=utf-8';
			}
		}
		return $content_type;
	}

	/**
	 * Replace Placeholder for recied data.
	 *
	 * @param array  $contact Get Contact which is created by webhook.
	 * @param string $key Contact key.
	 * @return mixed
	 */
	public function replace_form_value( $contact, $key ) {
		$email       = isset( $contact['email'] ) ? $contact['email'] : '';
		$first_name  = isset( $contact['first_name'] ) ? $contact['first_name'] : '';
		$last_name   = isset( $contact['last_name'] ) ? $contact['last_name'] : '';
		$city        = isset( $contact['meta_fields']['city'] ) ? $contact['meta_fields']['city'] : '';
		$state       = isset( $contact['meta_fields']['state'] ) ? $contact['meta_fields']['state'] : '';
		$country     = isset( $contact['meta_fields']['country'] ) ? $contact['meta_fields']['country'] : '';
		$company     = isset( $contact['meta_fields']['company'] ) ? $contact['meta_fields']['company'] : '';
		$designation = isset( $contact['meta_fields']['designation'] ) ? $contact['meta_fields']['designation'] : '';
		$address_1   = isset( $contact['meta_fields']['address_line_1'] ) ? $contact['meta_fields']['address_line_1'] : '';
		$address_2   = isset( $contact['meta_fields']['address_line_2'] ) ? $contact['meta_fields']['address_line_2'] : '';
		if ( preg_match( '/^{{contact\.[a-zA-Z]+}}$/', '{{contact.firstName}}' ) ) {
			$key = str_replace( '{{contact.firstName}}', $first_name, $key );
		}
		if ( preg_match( '/^{{contact\.[a-zA-Z]+}}$/', '{{contact.lastName}}' ) ) {
			$key = str_replace( '{{contact.lastName}}', $last_name, $key );
		}
		if ( preg_match( '/^{{contact\.[a-zA-Z]+}}$/', '{{contact.email}}' ) ) {
			$key = str_replace( '{{contact.email}}', $email, $key );
		}
		if ( preg_match( '/^{{contact\.[a-zA-Z]+}}$/', '{{contact.city}}' ) ) {
			$key = str_replace( '{{contact.city}}', $city, $key );
		}
		if ( preg_match( '/^{{contact\.[a-zA-Z]+}}$/', '{{contact.companyName}}' ) ) {
			$key = str_replace( '{{contact.companyName}}', $company, $key );
		}
		if ( preg_match( '/^{{contact\.[a-zA-Z]+}}$/', '{{contact.designation}}' ) ) {
			$key = str_replace( '{{contact.designation}}', $designation, $key );
		}
		if ( preg_match( '/^{{contact\.address_1+}}$/', '{{contact.address_1}}' ) ) {
			$key = str_replace( '{{contact.address_1}}', $address_1, $key );
		}
		if ( preg_match( '/^{{contact\.address_2+}}$/', '{{contact.address_2}}' ) ) {
			$key = str_replace( '{{contact.address_2}}', $address_2, $key );
		}
		return $key;
	}
}
