<?php
/**
 * Automation Hook action class for MRM Autoamtion
 *
 * Class Webhook
 *
 * @package MailMintPro\Mint\Internal
 */

namespace MailMintPro\Mint\Internal;

use MailMintPro\Mint\Internal\Traits\Singleton;
use MintMail\App\Internal\Automation\HelperFunctions;
use MintMailPro\Mint_Pro_Helper;
/**
 * Automation Hook action class for MRM Autoamtion
 *
 * Class Webhook
 *
 * @package MailMintPro\Mint\Internal\AutomationHooks
 */
class AutomationHooks {

	use Singleton;

	/**
	 * MainMint filter hook.
	 *
	 * @return void
	 */
	public function init() {
		add_filter( 'mint_supported_automation_actions', array( $this, 'mint_pro_automation_actions' ), 10, 1 );
		add_filter( 'mrm_automation_connectors', array( $this, 'mint_pro_automation_connectors' ), 10, 1 );
	}

	/**
	 * Add new action.
	 *
	 * @param array $actions Get action for automaiton.
	 * @return mixed
	 */
	public function mint_pro_automation_actions( $actions ) {
		$actions['createUser']        = 'Create user';
		$actions['createUserMeta']    = 'Create user meta';
		$actions['updateStatus']      = 'Update status';
		$actions['removeTag']         = 'Remove tag';
		$actions['addList']           = 'Add list';
		$actions['removeList']        = 'Remove list';
		$actions['condition']         = 'Condition';
		$actions['createCoupon']      = 'Create coupon';
		$actions['addContactNote']    = 'Add contact note';
		$actions['sequence']          = 'Email sequence';
		$actions['webHookOutgoing']   = 'Web Hook';
		$actions['specificTimeDelay'] = 'Specific Time Delay';
		$actions['stopAutomation']    = 'Stop Automation';

		return $actions;
	}

	/**
	 * Add new connector.
	 *
	 * @param array $connectors Get Connector.
	 * @return mixed
	 */
	public function mint_pro_automation_connectors( $connectors ) {
		if ( HelperFunctions::is_wc_active() ) {
			$connectors['woocommerce'] = array(
				'class_name' => 'ConnectorWoocommerce',
			);
		}

		if ( HelperFunctions::is_wpf_active() ) {
			$connectors['wpfunnels'] = array(
				'class_name' => 'ConnectorWpfunnels',
			);
		}

		if ( Mint_Pro_Helper::is_edd_active() ) {
			$connectors['edd'] = array(
				'class_name' => 'ConnectorEdd',
			);
		}

		if ( Mint_Pro_Helper::is_gform_active() ) {
			$connectors['gform'] = array(
				'class_name' => 'ConnectorGform',
			);
		}

		if ( Mint_Pro_Helper::is_tutor_active() ) {
			$connectors['tutor'] = array(
				'class_name' => 'ConnectorTutor',
			);
		}

		if ( Mint_Pro_Helper::is_jetform_active() ) {
			$connectors['jetform'] = array(
				'class_name' => 'ConnectorJetform',
			);
		}

		if ( Mint_Pro_Helper::is_fluentform_active() ) {
			$connectors['fluentforms'] = array(
				'class_name' => 'ConnectorFluentForm',
			);
		}

		if ( Mint_Pro_Helper::is_contact_form_7_active() ) {
			$connectors['contactform'] = array(
				'class_name' => 'ConnectorContactForm',
			);
		}

		if ( Mint_Pro_Helper::is_learndash_lms_active() ) {
			$connectors['learndash'] = array(
				'class_name' => 'ConnectorLearnDash',
			);
		}

		return $connectors;
	}


}
