<?php
/**
 * Edd triggers
 *
 * @package MintMail\App\Internal\Automation\Connector\trigger;
 */

namespace MintMail\App\Internal\Automation\Connector\Trigger;

use MintMail\App\Internal\Automation\HelperFunctions;
use Mint\Mrm\Internal\Traits\Singleton;
/**
 * Edd triggers
 *
 * @package MintMail\App\Internal\Automation\Connector
 */
class FluentFormTriggers {

	use Singleton;

	/**
	 * Connector name
	 *
	 * @var $connector_name
	 */
	public $connector_name = 'FluentForm';

	/**
	 * Initialization of Fluent Forms hooks
	 */
	public function init() {
		add_action( 'fluentform_submission_inserted', array( $this, 'mint_fluentform_submission_inserted' ), 20, 3 );
	}


	/**
	 * Validate trigger settings
	 *
	 * @param array $step_data Get Step data.
	 * @param array $data Get All data.
	 * @return bool
	 * @since 1.2.7
	 */
	public function validate_settings( $step_data, $data ) {
		if ( isset( $data['trigger_name'] ) && ( ( 'fluentform_submission_inserted' === $data['trigger_name'] ) ) ) {
			if ( isset( $step_data['automation_id'], $step_data['automation_id'] ) ) {
				$step_data = HelperFunctions::get_step_data( $step_data['automation_id'], $step_data['step_id'] );
			}
			if ( isset( $step_data['settings']['fluentform_settings']['form_id'] ) && 'any' !== $step_data['settings']['fluentform_settings']['form_id'] ) {
				if ( isset( $data['data']['form_id'] ) ) {
					return $data['data']['form_id'] == $step_data['settings']['fluentform_settings']['form_id']; //phpcs:ignore
				}
			} else {
				return false;
			}
		}
		return false;
	}

	/**
	 * Mint trigger for Fluent Forms submission inserted event.
	 *
	 * @param int    $entry_id The ID of the submitted form entry.
	 * @param array  $form_data The data submitted with the form.
	 * @param object $form The Fluent Forms form object.
	 *
	 * @return void
	 * @since 1.2.7
	 */
	public function mint_fluentform_submission_inserted( $entry_id, $form_data, $form ) {
		$user_data = array();
		if ( !empty( $form->id ) ) {
			if ( is_array( $form_data ) ) {
				$user_data          = array();
				$data               = array();
				$user_data['email'] = isset( $form_data['email'] ) ? $form_data['email'] : '';

				if ( isset( $form_data['names'] ) ) {
					$user_data['first_name'] = $form_data['names']['first_name'];
					$user_data['last_name']  = $form_data['names']['last_name'];
				}
			}
		}
		if ( $user_data && isset( $user_data['email'] ) ) {
			$data = array(
				'connector_name' => $this->connector_name,
				'trigger_name'   => 'fluentform_submission_inserted',
				'data'           => array(
					'user_email' => $user_data['email'],
					'first_name' => isset( $user_data['first_name'] ) ? $user_data['first_name'] : '',
					'last_name'  => isset( $user_data['last_name'] ) ? $user_data['last_name'] : '',
					'form_id'    => isset( $form->id ) ? $form->id : '',
				),
			);
			do_action( MINT_TRIGGER_AUTOMATION, $data );
		}
	}
}

