<?php
/**
 * Edd triggers
 *
 * @package MintMail\App\Internal\Automation\Connector\trigger;
 */

namespace MintMail\App\Internal\Automation\Connector\trigger;

use WPFunnels\Wpfnl_functions;
use MintMail\App\Internal\Automation\HelperFunctions;
use Mint\Mrm\Internal\Traits\Singleton;
/**
 * Edd triggers
 *
 * @package MintMail\App\Internal\Automation\Connector
 */
class JetformTriggers {

	use Singleton;



	/**
	 * Connector name
	 *
	 * @var $connector_name
	 */
	public $connector_name = 'Jetform';

	/**
	 * Initialization of Jetform hooks
	 */
	public function init() {
		// //phpcs:ignore ; add_action( 'jet-form-builder/form-handler/before-send', array( $this, 'mint_jetform_before_submission' ), 10, 1 ); //phpcs:ignore
		add_action( 'jet-form-builder/form-handler/after-send', array( $this, 'mint_jetform_after_submission' ), 10, 2 );
	}


	/**
	 * Validate trigger settings
	 *
	 * @param array $step_data Get Step data.
	 * @param array $data Get All data.
	 * @return bool
	 */
	public function validate_settings( $step_data, $data ) {
		if ( isset( $data['trigger_name'] ) && ( ( 'jetform_after_submit' === $data['trigger_name'] ) || 'jetform_before_submit' === $data['trigger_name'] ) ) {
			if ( isset( $step_data['automation_id'], $step_data['automation_id'] ) ) {
				$step_data = HelperFunctions::get_step_data( $step_data['automation_id'], $step_data['step_id'] );
			}
			if ( isset( $step_data['settings']['jetform_settings']['form_id'] ) && 'any' !== $step_data['settings']['jetform_settings']['form_id'] ) {
				if ( isset( $data['data']['form_id'] ) ) {
					return $data['data']['form_id'] == $step_data['settings']['jetform_settings']['form_id']; //phpcs:ignore
				}
			} else {
				return false;
			}
		}
		return false;
	}


	/**
	 * After jetform submission
	 *
	 * @param array $form Entry.
	 *
	 * @return void
	 * @since  1.0.0
	 */
	public function mint_jetform_before_submission( $form ) {
		$user_data = array();
		if ( !empty( $form->form_id ) ) {
			if ( isset( $form->form_id, $form->is_success ) && $form->is_success ) {
				$fields    = $form->request_handler->_fields;
				$user_data = array();
				$data      = array();
				foreach ( $fields as $field ) {
					if ( isset( $field['attrs'] ) ) {
						if ( isset( $field['attrs']['field_type'] ) ) {
							if ( 'email' === $field['attrs']['field_type'] ) {
								if ( isset( $field['attrs']['name'] ) ) {
									$data['name'] = $field['attrs']['name'];
								}
							}
						}
					}
				}

				$request_data = $form->action_handler->request_data;
				if ( isset( $data['name'] ) && isset( $request_data[ $data['name'] ] ) ) {
					$user_data['email'] = $request_data[ $data['name'] ];
				}
			}
		}
		if ( $user_data && isset( $user_data['email'] ) ) {
			$data = array(
				'connector_name' => $this->connector_name,
				'trigger_name'   => 'gform_after_submission',
				'data'           => array(
					'user_email' => $user_data['email'],
					'first_name' => isset( $user_data['first_name'] ) ? $user_data['first_name'] : '',
					'last_name'  => isset( $user_data['last_name'] ) ? $user_data['last_name'] : '',
					'form_id'    => isset( $form['id'] ) ? $form['id'] : '',
				),
			);
			do_action( MINT_TRIGGER_AUTOMATION, $data );
		}
	}


	/**
	 * After jetform send email
	 *
	 * @param array   $form Entry.
	 * @param boolean $is_success Success.
	 * @return void
	 */
	public function mint_jetform_after_submission( $form, $is_success ) {
		$user_data = array();
		if ( !empty( $form->form_id ) && $is_success ) {
			if ( isset( $form->form_id, $form->is_success ) && $form->is_success ) {
				$fields    = $form->request_handler->_fields;
				$user_data = array();
				$data      = array();
				foreach ( $fields as $field ) {
					if ( isset( $field['attrs'] ) ) {
						if ( isset( $field['attrs']['field_type'] ) ) {
							if ( 'email' === $field['attrs']['field_type'] ) {
								if ( isset( $field['attrs']['name'] ) ) {
									$data['name'] = $field['attrs']['name'];
								}
							}
						}
					}
				}

				$request_data = $form->action_handler->request_data;
				if ( isset( $data['name'] ) && isset( $request_data[ $data['name'] ] ) ) {
					$user_data['email'] = $request_data[ $data['name'] ];
				}
			}
		}
		if ( $user_data && isset( $user_data['email'] ) ) {
			$data = array(
				'connector_name' => $this->connector_name,
				'trigger_name'   => 'jetform_after_submit',
				'data'           => array(
					'user_email' => $user_data['email'],
					'first_name' => isset( $user_data['first_name'] ) ? $user_data['first_name'] : '',
					'last_name'  => isset( $user_data['last_name'] ) ? $user_data['last_name'] : '',
					'form_id'    => isset( $form->form_id ) ? $form->form_id : '',
				),
			);
			do_action( MINT_TRIGGER_AUTOMATION, $data );
		}
	}




}

